<?php
$translations = array(
	'General_Locale' => 'ro_RO.UTF-8',
	'General_TranslatorName' => 'astonsoftware',
	'General_TranslatorEmail' => 'astonsoftware@gmail.com',
	'General_EnglishLanguageName' => 'Romanian',
	'General_OriginalLanguageName' => 'Română',
	'General_LayoutDirection' => 'ltr',
	'General_HelloUser' => 'Salut, %s!',
	'General_OpenSourceWebAnalytics' => 'Analiza trafic web sursa libera',
	'General_Dashboard' => 'Panoul de control',
	'General_DashboardForASpecificWebsite' => 'Panol de control pentru un site',
	'General_MultiSitesSummary' => 'Toate site-urile',
	'General_AllWebsitesDashboard' => 'Panoul de control pentru toate site-urile',
	'General_API' => 'API',
	'General_Widgets' => 'Dispozitive',
	'General_Settings' => 'Setari',
	'General_GiveUsYourFeedback' => 'Trimite sesizarii!',
	'General_Unknown' => 'Necunoscut',
	'General_Never' => 'Niciodata',
	'General_Required' => '%s obligatoriu',
	'General_NotValid' => '%s nu este valid',
	'General_NotDefined' => '%s este nedefinit',
	'General_Id' => 'Id',
	'General_Error' => 'Eroare',
	'General_Warning' => 'Atentie',
	'General_BackToHomepage' => 'Intoarcere la pagina Piwik',
	'General_Yes' => 'Da',
	'General_No' => 'Nu',
	'General_Delete' => 'Stergere',
	'General_Report' => 'Raport',
	'General_Reports' => 'Rapoarte',
	'General_RelatedReport' => 'Raport asemănător',
	'General_RelatedReports' => 'Rapoarte asemănătoare',
	'General_Metric' => 'Metric',
	'General_Metrics' => 'Metrice',
	'General_Edit' => 'Editare',
	'General_Download' => 'Descarca',
	'General_Upload' => 'Incarca',
	'General_Ok' => 'Ok',
	'General_Close' => 'Inchide',
	'General_Cancel' => 'Anulează',
	'General_OrCancel' => 'sau %s Anuleaza %s',
	'General_Logout' => 'Iesire',
	'General_Username' => 'Nume utilizator',
	'General_Description' => 'Descriere',
	'General_Done' => 'Gata',
	'General_PoweredBy' => 'Oferit de',
	'General_RowsToDisplay' => 'Afişează liniile',
	'General_Name' => 'Nume',
	'General_Value' => 'Valoare',
	'General_Total' => 'Total',
	'General_AverageOrderValue' => 'Valoare medie a comenzii',
	'General_PurchasedProducts' => 'Produse cumparate',
	'General_EcommerceOrders' => 'Comenzi ecommerce',
	'General_AbandonedCarts' => 'Cosuri abandonate',
	'General_TotalRevenue' => 'Venit total',
	'General_ProductRevenue' => 'Venit produs',
	'General_AveragePrice' => 'Pret mediu',
	'General_AverageQuantity' => 'Cantitate medie',
	'General_UniquePurchases' => 'Cumparaturi unice',
	'General_ProductConversionRate' => 'Rata de conversie per produs',
	'General_Quantity' => 'Cantitate',
	'General_Price' => 'Pret',
	'General_Subtotal' => 'Subtotal',
	'General_Tax' => 'Taxe',
	'General_Shipping' => 'Livrare',
	'General_Discount' => 'Reducere',
	'General_Details' => 'Detalii',
	'General_Default' => 'Prestabilit',
	'General_Visit' => 'Vizite',
	'General_FromReferrer' => 'de la',
	'General_VisitorIP' => 'IP vizitator',
	'General_VisitorID' => 'ID vizitator',
	'General_VisitType' => 'Tip vizitator',
	'General_VisitTypeExample' => 'De exemplu, pentru a selecta toti vizitatorii care s-au intors pe site, inclusiv cei care au cumparat in trecut, cererea catre API ar include %s',
	'General_DaysSinceLastVisit' => 'Zile de la ultima vizita',
	'General_DaysSinceFirstVisit' => 'Zile de la prima vizita',
	'General_DaysSinceLastEcommerceOrder' => 'Zile de la ultima comanda',
	'General_NumberOfVisits' => 'Numar de vizite',
	'General_VisitConvertedGoal' => 'Vizite care au convertit in cel putin un Scop',
	'General_VisitConvertedGoalId' => 'Vizite care au convertit intr-un anumit Scop',
	'General_VisitConvertedNGoals' => 'Vizite convertite in %s scopuri',
	'General_NewVisitor' => 'Vizitator nou',
	'General_NewVisits' => 'Vizite noi',
	'General_ReturningVisitor' => 'Vizitator ce revine',
	'General_Visitor' => 'Vizitator',
	'General_Date' => 'Data',
	'General_Period' => 'Perioada',
	'General_ChooseDate' => 'Alege data',
	'General_Today' => 'Azi',
	'General_Yesterday' => 'Ieri',
	'General_CurrentWeek' => 'Saptamana curenta',
	'General_CurrentMonth' => 'Luna curenta',
	'General_CurrentYear' => 'Anul curent',
	'General_DateRange' => 'Interval:',
	'General_DateRangeInPeriodList' => 'Interval',
	'General_DateRangeFromTo' => 'De la %s la %s',
	'General_ApplyDateRange' => 'Aplica interval',
	'General_InvalidDateRange_js' => 'Interval invalid, va rugam mai incercati',
	'General_DateRangeFrom_js' => 'De la',
	'General_DateRangeTo_js' => 'la',
	'General_PreviousDays' => 'Ultimele %s zile (excluzand azi)',
	'General_LastDays' => 'Ultimele %s zile (incluzand azi)',
	'General_LoadingData' => 'Se incarca datele...',
	'General_Loading_js' => 'Se incarca...',
	'General_GoTo' => 'Du-te la %s',
	'General_Next' => 'Urmatorul',
	'General_Previous' => 'Anteriorul',
	'General_First' => 'Prima',
	'General_Search' => 'Cauta',
	'General_Others' => 'Altele',
	'General_Table' => 'Tabela',
	'General_Piechart' => 'Diagrama',
	'General_TagCloud' => 'Tag Cloud',
	'General_VBarGraph' => 'Vertical bar graph',
	'General_View' => 'Vezi',
	'General_OpenInNewWindow_js' => 'Deschide intr-o fereastra noua',
	'General_SaveImageOnYourComputer_js' => 'Pentru a salva imaginea pe computer, click dreapta pe imagine si selectati "Save Image As..."',
	'General_Refresh' => 'Reinprospateaza pagina',
	'General_Visitors' => 'Vizitatori',
	'General_ExportThisReport' => 'Exporta acest set de date in alt interval',
	'General_ExportAsImage_js' => 'Exporta ca imagine',
	'General_Export' => 'Exporta',
	'General_ParameterMustIntegerBetween' => 'Parametrul %s trebuie sa fie o valoare intreaga intre %s si %s.',
	'General_YourChangesHaveBeenSaved' => 'Schimbarile au fost salvate',
	'General_ErrorRequest' => 'Oops… problem during the request, please try again.',
	'General_ColumnNbUniqVisitors' => 'Vizitatori unici',
	'General_ColumnNbUniqVisitorsDocumentation' => 'Numarul de vizitatori unici pe site-ul dvs. Fiecare utilizator este numarat o singura data, chiar daca a vizitat site-ul de mai multe ori pe zi.',
	'General_ColumnNbVisits' => 'Vizite',
	'General_ColumnNbVisitsDocumentation' => 'Daca un vizitator vine pe site-ul dvs. pentru prima data sau daca viziteaza o pagina mai mult de 30 minute dupa prima afisare, aceasta va fi inregistrata ca o noua vizita',
	'General_ColumnPercentageVisits' => '% Vizite',
	'General_ColumnNbActions' => 'Actiuni',
	'General_ColumnNbActionsDocumentation' => 'Numarul de actiuni facute de vizitatori. Acestea pot fi afisari de pagina, descarcari sau click-uri pe link-uri externe',
	'General_NbActions' => 'Numarul de actiuni',
	'General_ColumnMaxActions' => 'Maxim de actiuni intr-o vizita',
	'General_ColumnSumVisitLength' => 'Timp total petrecut de vizitatori (in secunde)',
	'General_ColumnLabel' => 'Eticheta',
	'General_ColumnConversionRate' => 'Rata de conversie',
	'General_ColumnConversionRateDocumentation' => 'Procentajul de vizite care au dus la conversia unui scop',
	'General_ColumnActionsPerVisit' => 'Actiuni pe vizita',
	'General_ColumnActionsPerVisitDocumentation' => 'Numarul mediu de actiuni (afisari, descarcari sau click-uri externe) desfasurate in timpul vizitelor',
	'General_VisitDuration' => 'Durata medie per vizite (in secunde)',
	'General_ColumnAvgTimeOnSite' => 'Avg. Timp pe Site',
	'General_ColumnAvgTimeOnSiteDocumentation' => 'Durata medie a unei vizite (in secunde)',
	'General_ColumnVisitDuration' => 'Durata vizita (in secunde)',
	'General_ColumnBounceRate' => 'Rata crestere',
	'General_ColumnBounceRateDocumentation' => 'Procentajul de vizite care au avut o singura afisare. Vizitatorul a parasit site-ul direct de la pagina de intrare',
	'General_ColumnBounceRateForPageDocumentation' => 'Procentajul de vizite care au inceput si s-au terminat pe aceasta pagina',
	'General_ColumnPageBounceRateDocumentation' => 'Procentajul de vizite care au inceput pe aceasta pagina si au parasit imediat site-ul',
	'General_ColumnExitRate' => 'Rata de iesire',
	'General_ColumnExitRateDocumentation' => 'Procentajul de vizite care au parasit site-ul dupa ce au vizualizat aceasta pagina',
	'General_ColumnPageviews' => 'Pagini vizualizate',
	'General_ColumnPageviewsDocumentation' => 'De cate ori a fost vizitata pagina',
	'General_ColumnUniquePageviews' => 'Pagini vizualizate unice',
	'General_ColumnUniquePageviewsDocumentation' => 'Numarul de vizite care au inclus aceasta pagina. Daca pagina a fost afisata de mai multe ori in timpul unei vizite, aceasta este numarata o singura data.',
	'General_ColumnBounces' => 'Iesiri',
	'General_ColumnBouncesDocumentation' => 'Numarul de vizite care au inceput si s-au terminat pe aceasta pagina. Vizitatorul a parasit site-ul dupa ce a vazut aceasta pagina.',
	'General_ColumnUniqueEntrances' => 'Intrari unice',
	'General_ColumnEntrances' => 'Intrari',
	'General_ColumnEntrancesDocumentation' => 'Numarul de vizite care au inceput pe aceasta pagina',
	'General_ColumnExits' => 'Iesiri',
	'General_ColumnUniqueExits' => 'Iesiri unice',
	'General_ColumnExitsDocumentation' => 'Numarul de vizite care s-au terminat pe aceasta pagina',
	'General_ColumnAverageTimeOnPage' => 'Timp mediu pe pagina',
	'General_ColumnAverageTimeOnPageDocumentation' => 'Timpul mediu pe care vizitatorii il petrec pe aceasta pagina',
	'General_ColumnValuePerVisit' => 'Venit per vizita',
	'General_ColumnVisitsWithConversions' => 'Vizite cu conversii',
	'General_VisitsWith' => 'Vizite cu %s',
	'General_YearsDays' => '%1$s ani %2$s zile',
	'General_DaysHours' => '%1$s zile %2$s ore',
	'General_HoursMinutes' => '%1$s ore %2$s min',
	'General_MinutesSeconds' => '%1$s min %2$ss',
	'General_Seconds' => '%ss',
	'General_Save' => 'Salvare',
	'General_Faq' => 'FAQ',
	'General_ForExampleShort' => 'ex.',
	'General_YouMustBeLoggedIn' => 'Trebuie sa fiti logat pentru a accesa aceasta functionalitate.',
	'General_Website' => 'Website',
	'General_GeneralSettings' => 'Setari generale',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Permite arhivare Piwik sa porneasca atunci cand rapoartele sunt vizualizate din browser.',
	'General_ArchivingInlineHelp' => 'Pentru site-uri cu trafic mediu sau mare, este recomandata dezactivarea arhivari Piwik din browser. Recomandat sa faceti setup la un cron job pentru a procesa rapoarte Piwik in fiecare ora',
	'General_ArchivingTriggerDescription' => 'Recomandat pentru instalari mari, trebuie sa %ssetup un cron job%s pentru procesarea automata a rapoartelor',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Vedeti %sdocumentatie oficiala%s pentru mai multe informatii.',
	'General_ReportsContainingTodayWillBeProcessedAtMostEvery' => 'Rapoartele pentru azi (sau alt interval incluzand azi) vor fi procesate la maxim fiecare',
	'General_NSeconds' => '%s secunde',
	'General_SmallTrafficYouCanLeaveDefault' => 'Pentru site-uri cu trafic mic, puteti lasa intervalul %%s secunde si accesa rapoartele in timp real.',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'Pentru site-uri cu trafic mediu sau mare, este recomandata procesarea rapoartelor la fiecare jumate de ora (%s secunde) sau ora (%s secunde)',
	'General_RequiresFlash' => 'Afisarea graficelor in Piwik necesita Flash',
	'General_GraphHelp' => 'Mai multe informatii despre afisarea graficelor in Piwik',
	'General_DataForThisGraphHasBeenPurged' => 'Datele din acest grafic sunt mai vechi de %s luni şi au fost curăţate.',
	'General_NoDataForTagCloud' => 'No data for this tag cloud.',
	'General_DataForThisTagCloudHasBeenPurged' => 'Datele din acest nor de etichete sunt mai vechi de %s luni şi au fost curăţate.',
	'General_DisplaySimpleTable' => 'Afisarea unui tabel simplu',
	'General_DisplayTableWithMoreMetrics' => 'Afisarea unui tabel cu mai multi metrici',
	'General_DisplayTableWithGoalMetrics' => 'Afisarea unui tabel cu scopurile',
	'General_YouAreViewingDemoShortMessage' => 'Vizualizati o versiune demo a Piwik',
	'General_YouAreCurrentlyUsing' => 'Foloseşti Piwik %s.',
	'General_DownloadFullVersion' => '%1$sDescarcati%2$s versiunea full! Accesati %3$s',
	'General_NewUpdatePiwikX' => 'Update nou: Piwik %s',
	'General_AboutPiwikX' => 'Despre Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s este disponibil. %2$s Actualizeaza-l acum!%3$s (see %4$s changes%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s este disponibil. Va rugam notificati administratorul.',
	'General_NewReportsWillBeProcessedByCron' => 'Cand arhivarea Piwik nu este declansata de browser, rapoartele noi vor fi procesate de crontab',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Rapoartele vor fi procesate la maxim fiecare ora',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Presupunand ca arhivarea este rapida pentru configurarea dvs., puteti rula crobtab mai frecvent',
	'General_BackToPiwik' => 'Inapoi la Piwik',
	'General_ClickHere' => 'Click aici pentru mai multe informatii',
	'General_ShortMonth_1' => 'Ian',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Apr',
	'General_ShortMonth_5' => 'Mai',
	'General_ShortMonth_6' => 'Iun',
	'General_ShortMonth_7' => 'Iul',
	'General_ShortMonth_8' => 'Aug',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Oct',
	'General_ShortMonth_11' => 'Noi',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'Ianuarie',
	'General_LongMonth_2' => 'Februarie',
	'General_LongMonth_3' => 'Martie',
	'General_LongMonth_4' => 'Aprilie',
	'General_LongMonth_5' => 'Mai',
	'General_LongMonth_6' => 'Iunie',
	'General_LongMonth_7' => 'Iulie',
	'General_LongMonth_8' => 'August',
	'General_LongMonth_9' => 'Septembrie',
	'General_LongMonth_10' => 'Octombrie',
	'General_LongMonth_11' => 'Noiembrie',
	'General_LongMonth_12' => 'Decembrie',
	'General_ShortDay_1' => 'Lun',
	'General_ShortDay_2' => 'Mar',
	'General_ShortDay_3' => 'Mie',
	'General_ShortDay_4' => 'Joi',
	'General_ShortDay_5' => 'Vin',
	'General_ShortDay_6' => 'Sam',
	'General_ShortDay_7' => 'Dum',
	'General_LongDay_1' => 'Luni',
	'General_LongDay_2' => 'Marti',
	'General_LongDay_3' => 'Miercuri',
	'General_LongDay_4' => 'Joi',
	'General_LongDay_5' => 'Vineri',
	'General_LongDay_6' => 'Sambata',
	'General_LongDay_7' => 'Duminica',
	'General_Daily' => 'Zilnic',
	'General_Weekly' => 'Saptamanal',
	'General_Monthly' => 'Lunar',
	'General_DailyReports' => 'Rapoarte zilnice',
	'General_WeeklyReports' => 'Rapoarte săptămânale',
	'General_MonthlyReports' => 'Rapoarte lunare',
	'General_YearlyReports' => 'Rapoarte anuale',
	'General_RangeReports' => 'Particularizare perioadă',
	'General_ConfigFileIsNotWritable' => 'Fişierul de configurare  %s Piwik nu se poate scrie, e posibil ca o parte din modificările tale să nu se fi salvat. %s Schimbă permisiile fişierului de configurare pentru a-l putea modifica.',
	'General_ExceptionDatabaseVersion' => 'Versiunea dvs. %1$s este %2$s dar Piwik necesita minim %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'Versiunea clientului dvs. %1$s este %2$s, care este incompatibila cu versiunea de pe server, %3$s.',
	'General_ExceptionMissingFile' => 'Fisier lipsa: %s',
	'General_ExceptionFilesizeMismatch' => 'Nepotrivire la marime fisierului: %1$s (marime asteptata: %2$s, gasita: %3$s)',
	'General_ExceptionFileIntegrity' => 'A esuat verificare integritatii: %s',
	'General_ExceptionNonceMismatch' => 'Nu a putut fi verificat token-ul de securitate in acest formular',
	'General_PleaseSpecifyValue' => 'Va rugam specificati o valoare pentru \'%s\'.',
	'General_ExceptionMethodNotFound' => 'Metoda \'%s\' nu exista sau nu e valabila in modulul \'%s\'.',
	'General_ExceptionInvalidRendererFormat' => 'Formatul \'%s\' este invalid. Incercati-l pe oricare dintre acestea: %s.',
	'General_ExceptionInvalidReportRendererFormat' => 'Formatul raportului \'%s\' este invalid. Incercati-l pe oricare dintre acestea: %s.',
	'General_ExceptionInvalidStaticGraphType' => 'Tipul graficului static \'%s\' nu este valid. Încearcă unul din următoarele: %s.',
	'General_ExceptionInvalidAggregateReportsFormat' => 'Formatul rapoartelor agregate \'%s\' este invalid. Incercati-l pe oricare dintre acestea: %s.',
	'General_ExceptionInvalidPeriod' => 'Perioada \'%s\' nu este suportata. Incercati-o pe oricare dintre acestea: %s.',
	'General_ExceptionInvalidDateRange' => 'Data \'%s\' nu este un interval corect. Ar trebui sa aiba urmatorul format: %s.',
	'General_ExceptionGoalNotFound' => 'ID-ul scopului = %s nu a putut fi gasit.',
	'General_ExceptionUndeletableFile' => 'Nu s-a putut sterge %s',
	'General_ExceptionPrivilege' => 'Nu puteti accesa resursa pentru ca necesita acces la %s',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Nu puteti accesa resursa pentru ca necesita acces %s pentru cel putin un site',
	'General_ExceptionPrivilegeAccessWebsite' => 'Nu puteti accesa resursa pentru ca necesita acces %s pentru id-ul site-ului %d',
	'General_ExceptionInvalidArchiveTimeToLive' => 'Timpul de arhivare trebuie sa fie un numar de secunde mai mare de 0',
	'General_ExceptionConfigurationFileNotFound' => 'Fisierul de configurare {%s} nu a fost gasit.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'Fisierul de configurare {%s} nu a putut fi citit. Hosting-ul dvs. ar fi putut dezactiva %s.',
	'General_ExceptionInvalidToken' => 'Token invalid',
	'General_ExceptionInvalidDateFormat' => 'Formatul datei trebuie sa fie: %s sau alt cuvant cheie suportat de functia %s (vedeti %s pentru mai multe informatii)',
	'General_ExceptionLanguageFileNotFound' => 'Fisierul de limba \'%s\' nu a fost gasit.',
	'General_ExceptionUnableToStartSession' => 'Sesiunea nu a putut fi pornita',
	'General_ExceptionCheckUserIsSuperUserOrTheUser' => 'Utilizatorul trebuie să fie ori Super User ori utilizatorul  \'%s\' însuşi.',
	'General_WarningFileIntegritySkipped' => 'Mediu de development detectat. Verificare integritatii fisierelor a fost sarita.',
	'General_WarningFileIntegrityNoManifest' => 'Verificare integritatii fisierelor nu a putut fi efectuata din cauza lipsei manifest.inc.php.',
	'General_WarningFileIntegrityNoMd5file' => 'Verificare integritatii fisierelor nu a putut fi efectuata din cauza lipsei functiei md5_file()',
	'General_FileIntegrityWarningExplanation' => 'Verificare integritatii fisierelor a esuat si a raportat erori. Acest lucru s-a intamplat din cauza incarcarii partiale a unor fisiere Piwik. Ar trebui sa urcati din nou toate fisierele Piwik in mod BINARY si sa faceti refresh.',
	'General_UseSMTPServerForEmail' => 'Folositi server SMTP pentru email',
	'General_SmtpServerAddress' => 'Adresa server SMTP',
	'General_SmtpPort' => 'Port SMTP',
	'General_AuthenticationMethodSmtp' => 'Metoda autentificare pentru SMTP',
	'General_SmtpUsername' => 'Nume utilizator SMTP',
	'General_SmtpPassword' => 'Parola SMTP',
	'General_SmtpEncryption' => 'Encriptie SMTP',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Selectati "Da" daca vreti sa trimiteti email via serverul mentionat in locul functiei local mail',
	'General_OptionalSmtpPort' => 'Optional. Prestabilit la 25 pentru neecriptat si TLS SMTP, si 465 pentru SSL SMTP.',
	'General_OnlyUsedIfUserPwdIsSet' => 'Folosit numai daca utilizator/parola sunt setate, intrebati providerul daca nu sunteti sigur care metoda sa o folositi',
	'General_OnlyEnterIfRequired' => 'Introduceti nume utilizator numai daca serverul SMTP o cere',
	'General_OnlyEnterIfRequiredPassword' => 'Introduceti parola numai daca serverul SMTP o cere',
	'General_WarningPasswordStored' => '%sAtentie:%s Parola va fi stocata in fisierul config vizibil oricui il poate accesa.',
	'General_EncryptedSmtpTransport' => 'Introduceti transport layer encryption cerut de serverul SMTP',
	'General_InvalidResponse' => 'Datele primite sunt invalide',
	'General_ChooseLanguage' => 'Alegeti limba',
	'General_ChoosePeriod' => 'Alegeti interval',
	'General_ChooseWebsite' => 'Alegeti website',
	'General_Language' => 'Limba',
	'General_PleaseUpdatePiwik' => 'Va rugam actualizati Piwik',
	'General_RequestTimedOut' => 'Un request la %s a expirat. Va rugam incercati din nou.',
	'General_UsePlusMinusIconsDocumentation' => 'Folositi semnele de plus si minus din stanga pentru navigare',
	'General_BrokenDownReportDocumentation' => 'Este segmentat in diferite rapoarte, afisate in josul paginii. Puteti mari graficele facand click pe rapoartele pe care doriti sa le vedeti.',
	'General_ChangeTagCloudView' => 'Va rugam notati, puteti vizualiza rapoartele in alte feluri, pe langa tag cloud. Folositi controalele din josul raportului pentru a face asta',
	'General_Recommended' => '(recomandat)',
	'General_NotRecommended' => '(nerecomandat)',
	'General_Goal' => 'Scop',
	'General_Outlink' => 'Link extern',
	'General_Help' => 'Ajutor',
	'General_DailySum' => 'suma zilnica',
	'General_AfterEntry' => 'dupa introducerea aici',
	'General_Metadata' => 'Metadata',
	'General_OneVisit' => '1 vizita',
	'General_NVisits' => '%s vizite',
	'General_OneDay' => '1 zi',
	'General_NDays' => '%s zile',
	'General_MainMetrics' => 'Metrici principali',
	'General_Mobile' => 'Mobil',
	'General_Desktop' => 'Desktop',
	'General_Rows' => 'Linii',
	'General_GeneralInformation' => 'Informaţii Generale',
	'Actions_PluginDescription' => 'Rapoarte despre numărul de pagini văzute, outlink-uri şi descărcări. Outlink-uri şi Descărcările sunt urmărite automat!',
	'Actions_Actions' => 'Actiune',
	'Actions_SubmenuPages' => 'Pagini',
	'Actions_SubmenuPagesEntry' => 'Pagini de intrare',
	'Actions_SubmenuPagesExit' => 'Pagini de ieşire',
	'Actions_WidgetPagesExit' => 'Pagini de iesire',
	'Actions_EntryPageTitles' => 'Titlurile paginilor de intrare',
	'Actions_ExitPageTitles' => 'Titlurile paginilor de ieşire',
	'Actions_WidgetExitPageTitles' => 'Titlurile paginii de iesire',
	'Actions_SubmenuPageTitles' => 'Titluri pagini',
	'Actions_WidgetSearchCategories' => 'Categorii de cautare',
	'Actions_WidgetSearchNoResultKeywords' => 'Interogari de cautare fara rezultat',
	'Actions_PageUrls' => 'URL-uri pagini',
	'Actions_SubmenuOutlinks' => 'Linkuri externe',
	'Actions_SubmenuDownloads' => 'Descarcari',
	'Actions_SubmenuSitesearch' => 'Cautare pe site',
	'Actions_PagesReportDocumentation' => 'Acest raport conţine informaţii despre URL-urile paginilor ce au fost vizitate. %s Acest tabel este organizat ierarhic,URL-urile sunt afişate într-o structură tip arbore.',
	'Actions_PageTitlesReportDocumentation' => 'Acest raport conţine informaţii despre titlurile paginilor ce au fost vizitate. %s Titlul paginii este Tag-ul HTML %s afişat de cele mai multe browsere ca nume al ferestrei.',
	'Actions_OutlinksReportDocumentation' => 'Acest raport arată o listă ierarhică al URL-urilor outlink-urilor ce au fost click-uite de vizitatorii tăi.',
	'Actions_OutlinkDocumentation' => 'Un outlink este un link ce trimite vizitatori de pe website-ul tău (către alt domeniu).',
	'Actions_DownloadsReportDocumentation' => 'În acest raport, poţi vedea ce fişiere au fost descărcate de vizitatorii tăi. %s Ceea ce Piwik socoteşte ca fiind o descărcare este un click pe un link de descărcare. Dacă a fost terminată sau nu nu este cunoscut de către Piwik.',
	'Actions_ColumnClicks' => 'Click-uri',
	'Actions_ColumnClicksDocumentation' => 'Numărul de ori link-ul a fost click-uit.',
	'Actions_ColumnUniqueClicks' => 'Click-uri unice.',
	'Actions_ColumnUniqueClicksDocumentation' => 'Numărul de vizite ce a presupus un click pe acest link. Dacă un link a fost click-uit de mai multe ori în timpul unei vizite, este numărat o dată.',
	'Actions_ColumnDownloads' => 'Descărcări',
	'Actions_ColumnUniqueDownloads' => 'Descărcări Unice',
	'Actions_ColumnOutlinks' => 'Outlink-uri',
	'Actions_ColumnUniqueOutlinks' => 'Outlink-uri Unice',
	'Actions_ColumnPageName' => 'Numele Paginii',
	'Actions_ColumnPageURL' => 'URL-ul Paginii',
	'Actions_ColumnSearchCategory' => 'Categorie căutare',
	'Actions_ColumnSearchKeyword' => 'Cuvant cheie',
	'Actions_SiteSearchKeyword' => 'Intereogare (Cautare pe site)',
	'Actions_ColumnClickedURL' => 'URL-uri Click-uite',
	'Actions_ColumnDownloadURL' => 'URL Descărcare',
	'Actions_ColumnEntryPageURL' => 'URL Paginii de Intrare',
	'Actions_ColumnEntryPageTitle' => 'Titlul Paginii de Intrare',
	'Actions_ColumnExitPageURL' => 'URL-ul Paginii de Ieşire',
	'Actions_ColumnExitPageTitle' => 'Titlul Paginii de Ieşire',
	'Actions_ColumnNoResultKeyword' => 'Cuvânt cheie fără rezultate în căutări',
	'Actions_ColumnSearches' => 'Căutări',
	'Actions_ColumnSiteSearchKeywords' => 'Cuvinte cheie unice',
	'Actions_ColumnSearchesDocumentation' => 'Numărul de vizite care au căutat după acest cuvânt cheie folosind motorul de căutare de pe site-ul dvs web.',
	'Actions_ColumnPagesPerSearch' => 'Pagini cu rezultate căutări',
	'Actions_ColumnPagesPerSearchDocumentation' => 'Vizitatorii vor căuta pe site-ul dvs web şi uneori vor apăsa "următorul" pentru a vizualiza mai multe rezultate. Acesta este numărul mediu de pagini cu rezultate ale căutării vizualizate pentru acest cuvânt cheie.',
	'Actions_EntryPagesReportDocumentation' => 'Acest raport conţinte informaţii despre paginile de intrare ce au fost folosite în perioada specificată. O pagină de intrare este prima pagină ce a fost văzută de un vizitator în timpul vizitei sale. %s URL-urile de intrare sunt afişate într-o structură arborescentă.',
	'Actions_EntryPageTitlesReportDocumentation' => 'Acest raport conţine informaţii despre titlurile paginilor de intrare ce au fost folosite în timpul perioadei specificate.',
	'Actions_ExitPagesReportDocumentation' => 'Acest raport conţine informaţii despre paginile de ieşire ce au fost folosite în timpul perioadei specificate. O pagină de ieşire este ultima pagină ce a fost văzută de un vizitator în timpul vizitei sale. %s URL-urile de ieşire sunt afişate ca o structură tip arbore.',
	'Actions_ExitPageTitlesReportDocumentation' => 'Acest raport conţine informaţii despre titlurile paginilor de ieşire ce au fost folosite în timpul perioadei specificate.',
	'AnonymizeIP_PluginDescription' => 'Ascunde ultimele cifre ale IP-ului vizitatorilor pentru a fi în conformitate cu legile privind protecţia datelor personale.',
	'API_QuickDocumentationTitle' => 'Demonstrare rapida API',
	'API_UserAuthentication' => 'Identificare utilizator',
	'API_LoadedAPIs' => 'Incarcare de succes %s al API',
	'CoreAdminHome_Administration' => 'Administrare',
	'CoreAdminHome_EmailServerSettings' => 'Setarile serverului email',
	'CoreAdminHome_JSTracking_CustomCampaignQueryParamDesc' => 'Nota: %1$sPiwik va detecta automat parametrii Google Analytics.%2$s',
	'CoreAdminHome_ImageTracking' => 'Urmarire prin imagine',
	'CoreAdminHome_ImageTrackingLink' => 'Legatura de urmarire prin imagine',
	'CoreAdminHome_JavaScriptTracking' => 'Urmarire prin JavaScript',
	'CoreHome_CategoryNoData' => 'Nici o data in aceasta categorie. Incearca "Include toata populatia".',
	'CoreHome_ShowJSCode' => 'Arat codul  javascript ce trebuie folosit',
	'CoreHome_PageOf_js' => '%1$s al %2$s',
	'CoreHome_PeriodDay' => 'Zi',
	'CoreHome_PeriodWeek' => 'Saptamana',
	'CoreHome_PeriodMonth' => 'Luna',
	'CoreHome_PeriodYear' => 'An',
	'General_DaySu_js' => 'Du',
	'General_DayMo_js' => 'Lu',
	'General_DayTu_js' => 'Ma',
	'General_DayWe_js' => 'Mi',
	'General_DayTh_js' => 'Jo',
	'General_DayFr_js' => 'Vi',
	'General_DaySa_js' => 'Sâ',
	'General_ShortDay_1_js' => 'Dum',
	'General_ShortDay_2_js' => 'Lun',
	'General_ShortDay_3_js' => 'Mar',
	'General_ShortDay_4_js' => 'Mie',
	'General_ShortDay_5_js' => 'Joi',
	'General_ShortDay_6_js' => 'Vin',
	'General_ShortDay_7_js' => 'Sâm',
	'General_LongDay_1_js' => 'Duminică',
	'General_LongDay_2_js' => 'Luni',
	'General_LongDay_3_js' => 'Marţi',
	'General_LongDay_4_js' => 'Miercuri',
	'General_LongDay_5_js' => 'Joi',
	'General_LongDay_6_js' => 'Vineri',
	'General_LongDay_7_js' => 'Sâmbătă',
	'General_ShortMonth_1_js' => 'Ian',
	'General_ShortMonth_2_js' => 'Feb',
	'General_ShortMonth_3_js' => 'Mar',
	'General_ShortMonth_4_js' => 'Apr',
	'General_ShortMonth_5_js' => 'Mai',
	'General_ShortMonth_6_js' => 'Iun',
	'General_ShortMonth_7_js' => 'Iul',
	'General_ShortMonth_8_js' => 'Aug',
	'General_ShortMonth_9_js' => 'Sep',
	'General_ShortMonth_10_js' => 'Oct',
	'General_ShortMonth_11_js' => 'Nov',
	'General_ShortMonth_12_js' => 'Dec',
	'General_MonthJanuary_js' => 'Ianuarie',
	'General_MonthFebruary_js' => 'Februarie',
	'General_MonthMarch_js' => 'Martie',
	'General_MonthApril_js' => 'Aprilie',
	'General_MonthMay_js' => 'Mai',
	'General_MonthJune_js' => 'Iunie',
	'General_MonthJuly_js' => 'Iulie',
	'General_MonthAugust_js' => 'August',
	'General_MonthSeptember_js' => 'Septembrie',
	'General_MonthOctober_js' => 'Octombrie',
	'General_MonthNovember_js' => 'Noiembrie',
	'General_MonthDecember_js' => 'Decembrie',
	'CorePluginsAdmin_Plugins' => 'Pluginuri',
	'CorePluginsAdmin_PluginsManagement' => 'Managementul pluginurilor',
	'CorePluginsAdmin_MainDescription' => 'Pluginurile extind functionaliatatea lui Piwik. Orice plugin instalat , poate fi activat sau dezactivat aici.',
	'CorePluginsAdmin_Plugin' => 'Pluginuri',
	'CorePluginsAdmin_Version' => 'Versiuni',
	'CorePluginsAdmin_Status' => 'Stare',
	'CorePluginsAdmin_Action' => 'Actiune',
	'CorePluginsAdmin_PluginHomepage' => 'Pagina Pluginurilor',
	'CorePluginsAdmin_Activated' => 'Activare',
	'CorePluginsAdmin_Active' => 'Activ',
	'CorePluginsAdmin_Inactive' => 'Inactiv',
	'CorePluginsAdmin_Deactivate' => 'Dezactivare',
	'CorePluginsAdmin_Activate' => 'Activare',
	'CorePluginsAdmin_MenuPlugins' => 'Pluginuri',
	'CoreUpdater_UpdateTitle' => 'Piwik › Actualizare',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Actualizare necesara a bazei de date',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Baza ta de date este expirata, si trebuie actualizata inainte de a continua.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Baza de date Piwik va fi upgradata pentru versiunea %1$s la noua versiune %2$s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Urmatoarele pluginuri vor fi actualizate: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Procesul de actualizarea al bazei de date va dura ceva timp, deci aveti putina rabdare.',
	'CoreUpdater_UpgradePiwik' => 'Actualizea-za Piwik',
	'CoreUpdater_HelpMessageContent' => 'Verifica %1$s Piwik FAQ %2$s ce explica cele mai comune errori privind actualizarea. %3$s Intreaba administratorul de sistem - daca te poate ajuta sa rezolvi erorile ce tin de server si setarile MySQL .',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Eroare critica a procesului de actualizare :',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Eroare de core . Consulta documentatia de ajutor:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Actualizarea s-a efectuat cu succes, oricum mai sunt cateva lucruri ce sunt necesare pentru a finaliza procesul . Citeste descrierea pentru detalii. Pentru ajutor:',
	'CoreUpdater_UpgradeComplete' => 'Actualizare completa!',
	'CoreUpdater_WarningMessages' => 'Mesaj avertisment:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Eroare in actualizarea pluginurilor:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Au fost dezactivate urmatoarele pluginuri : %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik s-a actualizat cu succes!',
	'CoreUpdater_ContinueToPiwik' => 'Continua catre Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Actualizare automata',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Nu este disponibila o noua versiune actualizata Piwik',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Poti actualiza versiunea %s automat sau puteti o instala manual :',
	'CoreUpdater_DownloadX' => 'Descarca %s',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Se verifica fisierele impachetate',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Creaza o copie a fisierului configuratie in %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Instaleaza ultima versiune',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik actualizat cu succes!',
	'Dashboard_PluginDescription' => 'Tabloul tău de control. Poţi particulariza tabloul tău de control: adaugă noi widget-uri, schimbă ordinea widget-urilor. Fiecare utilizator îşi poate accesa tabloul său de control particularizat.',
	'Dashboard_Dashboard' => 'Tablou de bord',
	'Dashboard_AddAWidget' => 'Adaugă un widget',
	'Dashboard_DeleteWidgetConfirm' => 'Esti sigur ca doresti sa stergi dispozitivul din  tabloul de bord ?',
	'Dashboard_SelectWidget' => 'Selecteaza dispozitivul ce doresti sa-l adaugi in tabloul de bord',
	'Dashboard_AddPreviewedWidget_js' => 'Dă click ca să adaugi un widget la tabloul tău de control',
	'Dashboard_WidgetPreview_js' => 'Previzualizează widget-ul',
	'Dashboard_Close_js' => 'Închide',
	'Dashboard_Maximise_js' => 'Maximizează',
	'Dashboard_Minimise_js' => 'Minimizează',
	'Dashboard_TitleWidgetInDashboard_js' => 'Dispozitivul este in tabloul de bord',
	'Dashboard_TitleClickToAdd_js' => 'Adauga la tabloul de bord',
	'Dashboard_LoadingWidget_js' => 'Se incarca dispozitivul, asteapta...',
	'Dashboard_WidgetNotFound_js' => 'Dispozitivul nu exista',
	'Dashboard_ResetDashboard' => 'Resetează tabloul de control',
	'Dashboard_ResetDashboardConfirm' => 'Eşti sigur(ă) că vrei să resetezi aspectul tabloului de control la selecţia implicită de Widget-uri?',
	'Dashboard_WidgetsAndDashboard' => 'Widget-uri & Tabloul de control',
	'Dashboard_ChangeDashboardLayout' => 'Schimbă aşezarea tabloului de control',
	'Dashboard_SelectDashboardLayout' => 'Te rog selectează aşezarea noului tablou de control',
	'Dashboard_DashboardOf' => 'Tabloul de control %s',
	'Dashboard_ManageDashboard' => 'Administreză tablou de comandă',
	'Dashboard_CreateNewDashboard' => 'Creează un tablou de comandă nou',
	'Dashboard_RenameDashboard' => 'Redenumeşte tabloul de comandă',
	'Dashboard_DashboardName' => 'Numele tabloului de comandă:',
	'Dashboard_EmptyDashboard' => 'Tablou de comandă gol - Alege-ţi widget-urile preferate',
	'Dashboard_DefaultDashboard' => 'Tablou de comandă implicit - Folosind widget-urile selectate şi coloanele implicite',
	'Dashboard_RemoveDashboard' => 'Şterge tabloul de comandă',
	'Dashboard_SetAsDefaultWidgets' => 'Stabileşte ca implicită selecţia de widget-uri',
	'Dashboard_SetAsDefaultWidgetsConfirm' => 'Eşti sigur(ă) că vrei să stabileşti selecţia curentă de widget-uri şi aşezarea tabloului de comandă ca fiind şablonul implicit al tabloului de comandă?',
	'Dashboard_SetAsDefaultWidgetsConfirmHelp' => 'Această selecţie de widget-uri şi aşezarea coloanelor tabloului de comandă va fi folosită când un utilizator creează un tablou de comandă nou sau când caracteristica "%s" este folosită.',
	'Dashboard_RemoveDashboardConfirm' => 'Eşti sigur(ă) că vrei să ştergi tabloul de comandă "%s"?',
	'Dashboard_NotUndo' => 'Nu o să poţi revoca acestă operaţie.',
	'Dashboard_DashboardEmptyNotification' => 'Tabloul tău de comandă nu conţine niciun widget. Începi prin a adăuga câteva widget-uri sau doar resetează tabloul de comandă către selecţia implicită de widget-uri.',
	'DBStats_DatabaseUsage' => 'Utilizare baza date',
	'DBStats_MainDescription' => 'Piwik stocheaza toate datele statistice in baza de date Mysql . Curent, tabela Piwik utilizeaza %s.',
	'DBStats_Table' => 'Tabela',
	'DBStats_DataSize' => 'Marime date',
	'DBStats_IndexSize' => 'Marime index',
	'DBStats_TotalSize' => 'Marime totala',
	'Installation_Installation' => 'Installation',
	'Installation_InstallationStatus' => 'Installation status',
	'Installation_PercentDone' => '%s %% Done',
	'Installation_NoConfigFound' => 'The Piwik configuration file couldn\'t be found and you are trying to access a Piwik page.<br /><b>  » You can <a href=\'index.php\'>install Piwik now</a></b><br /><small>If you installed Piwik before and have some tables in your DB, don\'t worry, you can reuse the same tables and keep your existing data!</small>',
	'Installation_JsTag' => 'Javascript tag',
	'Installation_Congratulations' => 'Congratulations',
	'Installation_CongratulationsHelp' => '<p>Congratulations! Your Piwik installation is complete.</p><p>Make sure your javascript code is entered on your pages, and wait for your first visitors!</p>',
	'Installation_ContinueToPiwik' => 'Continue to Piwik',
	'Installation_SetupWebsite' => 'Setup a website',
	'Installation_SetupWebsiteError' => 'There was an error when adding the website',
	'Installation_SuperUserLogin' => 'super user login',
	'Installation_Password' => 'password',
	'Installation_PasswordRepeat' => 'password (repeat)',
	'Installation_Email' => 'email',
	'Installation_SecurityNewsletter' => 'email me with major Piwik upgrades and security alerts',
	'Installation_CommunityNewsletter' => 'email me with community updates (new plugins, new features, etc.)',
	'Installation_PasswordDoNotMatch' => 'password do not match',
	'Installation_SystemCheck' => 'System check',
	'Installation_SystemCheckPhp' => 'PHP version',
	'Installation_SystemCheckWriteDirs' => 'Directories with write access',
	'Installation_SystemCheckWriteDirsHelp' => 'To fix this error on your Linux system, try typing in the following command(s)',
	'Installation_SystemCheckMemoryLimit' => 'Memory limit',
	'Installation_SystemCheckMemoryLimitHelp' => 'On a high traffic website, the archiving process may require more memory than currently allowed.<br />See the directive memory_limit in your php.ini file if necessary.',
	'Installation_SystemCheckGD' => 'GD > 2.x (graphics)',
	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
	'Installation_SystemCheckTimeLimitHelp' => 'On a high traffic website, executing the archiving process may require more time than currently allowed.<br />See the directive max_execution_time  in your php.ini file if necessary',
	'Installation_SystemCheckError' => 'An error occured - must be fixed before you proceed',
	'Installation_SystemCheckWarning' => 'Piwik will work normally but some features may be missing',
	'Installation_Tables' => 'Creating the tables',
	'Installation_TablesFound' => 'The following tables have been found in the database',
	'Installation_TablesWarningHelp' => 'Either choose to reuse the existing database tables or select a clean install to erase all existing data in the database.',
	'Installation_TablesReuse' => 'Reuse the existing tables',
	'Installation_TablesDelete' => 'Delete the detected tables',
	'Installation_TablesDeletedSuccess' => 'Existing Piwik tables deleted with success',
	'Installation_TablesCreatedSuccess' => 'Tables created with success!',
	'Installation_DatabaseCreatedSuccess' => 'Database %s created with success!',
	'Installation_Welcome' => 'Bine ai venit!',
	'Installation_WelcomeHelp' => '<p>Piwik is an open source web analytics software that makes it easy to get the information you want from your visitors.</p><p>This process is split up into %s easy steps and will take around 5 minutes.</p>',
	'Login_PluginDescription' => 'Modul de autentintificare, ce citeşte credenţialele din fişierul config/config.inc.php pentru Super User şi din Baza de date pentru alţi useri. Poate fi uşor schimbat pentru a folosi un nou mecanism de Autentificare (OpenID, htaccess, custom Auth, etc.).',
	'Login_LoginPasswordNotCorrect' => 'Numele si parola nu sunt corecte',
	'Login_Password' => 'Parola',
	'Login_PasswordRepeat' => 'Parolă (repetă)',
	'Login_ChangePassword' => 'Schimbă parola',
	'Login_LoginOrEmail' => 'Login sau E-mail',
	'Login_RememberMe' => 'Ţine-mă minte',
	'Login_LogIn' => 'Intrare',
	'Login_Logout' => 'Iesire',
	'Login_LostYourPassword' => 'Ai pierdut parola?',
	'Login_PasswordsDoNotMatch' => 'Parolele nu se potrivesc.',
	'Login_InvalidUsernameEmail' => 'Nume/adresa mail invalida',
	'Login_InvalidOrExpiredToken' => 'Jetonul este invalid sau expirat.',
	'Login_ContactAdmin' => 'Motiv posibil: gazda ta poate avea dezactivata functia email . <br/>Contactati adminstratorul.',
	'Login_ExceptionPasswordMD5HashExpected' => 'Parametrul parolei este aşteptat să fie un hash MD5 al parolei.',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Super Userul nu poate fi autentificat folosind \'%s\' mecanism.',
	'Provider_WidgetProviders' => 'Provideri',
	'Provider_SubmenuLocationsProvider' => 'Locatie si provideri',
	'Referers_Referers' => 'Referinte',
	'Referers_SearchEngines' => 'Motoare cautare',
	'Referers_Keywords' => 'Cuvinte',
	'Referers_DirectEntry' => 'Intrare directa',
	'Referers_Websites' => 'Siteuri',
	'Referers_Campaigns' => 'Campanii',
	'Referers_Evolution' => 'Evolutii in afara perioadei',
	'Referers_Type' => 'Tipuri referinta',
	'Referers_TypeDirectEntries' => '%s intrari directe',
	'Referers_TypeSearchEngines' => '%s de la motoare cautare',
	'Referers_TypeWebsites' => '%s de la siteuri',
	'Referers_TypeCampaigns' => '%s de la campanii',
	'Referers_SubmenuSearchEngines' => 'Motoare cautare si cuvinte',
	'Referers_SubmenuWebsites' => 'Siteuri',
	'Referers_SubmenuCampaigns' => 'Campanii',
	'Referers_WidgetKeywords' => 'Lista cuvintelor',
	'Referers_WidgetCampaigns' => 'Lista campaniilor',
	'Referers_WidgetExternalWebsites' => 'Lista siteurilor externe',
	'Referers_WidgetSearchEngines' => 'Cel mai bun motor cautare',
	'Referers_WidgetOverview' => 'Rezumat',
	'SEO_SeoRankings' => 'Poziţionări SEO',
	'SEO_AlexaRank' => 'Poziţie în Alexa',
	'SEO_DomainAge' => 'Vechime domeniu',
	'SEO_Rank' => 'Poziţie',
	'SEO_Pages' => 'Pagini',
	'SEO_SEORankingsFor' => 'Poziţionări SEO pentru %s',
	'SitesManager_Sites' => 'Situri',
	'SitesManager_WebsitesManagement' => 'Mangementul siteurilor',
	'SitesManager_MainDescription' => 'Your Web Analytics reports need Websites! Add, update, delete Websites, and show the Javascript to insert in your pages.',
	'SitesManager_NoWebsites' => 'You don\'t have any website to administrate.',
	'SitesManager_AddSite' => 'Adauga un site',
	'SitesManager_Urls' => 'Adresa',
	'SitesManager_MenuSites' => 'Situri',
	'SitesManager_DeleteConfirm_js' => 'Are you sure you want to delete the website %s?',
	'SitesManager_ExceptionDeleteSite' => 'It is not possible to delete this website as it is the only registered website. Add a new website first, then delete this one.',
	'SitesManager_ExceptionNoUrl' => 'You must specify at least one URL for the site.',
	'SitesManager_ExceptionEmptyName' => 'The site name can\'t be empty.',
	'SitesManager_ExceptionInvalidUrl' => 'The url \'%s\' is not a valid URL.',
	'TranslationsAdmin_MenuTranslations' => 'Traducere',
	'TranslationsAdmin_MenuLanguages' => 'Limba',
	'TranslationsAdmin_LanguageCode' => 'Cod limba',
	'TranslationsAdmin_Plugin' => 'Plugin',
	'TranslationsAdmin_Definition' => 'Definitie',
	'TranslationsAdmin_DefaultString' => 'Limba curenta (English)',
	'TranslationsAdmin_TranslationString' => 'Traducere (Limba curenta: %s)',
	'TranslationsAdmin_Translations' => 'Traducere',
	'TranslationsAdmin_FixPermissions' => 'Rezolva permisiile fisierelor',
	'TranslationsAdmin_AddLanguage' => 'Adauga limba',
	'TranslationsAdmin_Export' => 'Exporta limba',
	'TranslationsAdmin_Import' => 'Importa limba',
	'UserCountry_Country' => 'Tara',
	'UserCountry_Continent' => 'Continent',
	'UserCountry_DistinctCountries' => '%s tari distincte',
	'UserCountry_SubmenuLocations' => 'Locatie',
	'UserCountry_country_ac' => 'Ascension Islands',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'United Arab Emirates',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua and Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'Netherlands Antilles',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarctica',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'American Samoa',
	'UserCountry_country_at' => 'Austria',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Aland Islands',
	'UserCountry_country_az' => 'Azerbaijan',
	'UserCountry_country_ba' => 'Bosnia and Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgium',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthelemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brazil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvet Island',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Belarus',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Canada',
	'UserCountry_country_cc' => 'Cocos (Keeling) Islands',
	'UserCountry_country_cd' => 'Congo, The Democratic Republic of the',
	'UserCountry_country_cf' => 'Central African Republic',
	'UserCountry_country_cg' => 'Congo',
	'UserCountry_country_ch' => 'Switzerland',
	'UserCountry_country_ci' => 'Cote D\'Ivoire',
	'UserCountry_country_ck' => 'Cook Islands',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Cameroon',
	'UserCountry_country_cn' => 'China',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cp' => 'Clipperton Island',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cape Verde',
	'UserCountry_country_cx' => 'Christmas Island',
	'UserCountry_country_cy' => 'Cyprus',
	'UserCountry_country_cz' => 'Czech Republic',
	'UserCountry_country_de' => 'Germany',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Denmark',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'Dominican Republic',
	'UserCountry_country_dz' => 'Algeria',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egypt',
	'UserCountry_country_eh' => 'Western Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spain',
	'UserCountry_country_et' => 'Ethiopia',
	'UserCountry_country_eu' => 'European Union',
	'UserCountry_country_fi' => 'Finland',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falkland Islands (Malvinas)',
	'UserCountry_country_fm' => 'Micronesia, Federated States of',
	'UserCountry_country_fo' => 'Faroe Islands',
	'UserCountry_country_fr' => 'France',
	'UserCountry_country_fx' => 'France, Metropolitan',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Great Britain',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgia',
	'UserCountry_country_gf' => 'French Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Greenland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Equatorial Guinea',
	'UserCountry_country_gr' => 'Greece',
	'UserCountry_country_gs' => 'South Georgia and the South Sandwich Islands',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard Island and McDonald Islands',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Croatia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hungary',
	'UserCountry_country_ic' => 'Canary Islands',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Ireland',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Man Island',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'British Indian Ocean Territory',
	'UserCountry_country_iq' => 'Iraq',
	'UserCountry_country_ir' => 'Iran, Islamic Republic of',
	'UserCountry_country_is' => 'Iceland',
	'UserCountry_country_it' => 'Italy',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordan',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kyrgyzstan',
	'UserCountry_country_kh' => 'Cambodia',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Saint Kitts and Nevis',
	'UserCountry_country_kp' => 'Korea, Democratic People\'s Republic of',
	'UserCountry_country_kr' => 'Korea, Republic of',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Cayman Islands',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Lebanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lithuania',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Latvia',
	'UserCountry_country_ly' => 'Libya',
	'UserCountry_country_ma' => 'Morocco',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldova, Republic of',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Marshall Islands',
	'UserCountry_country_mk' => 'Macedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Northern Mariana Islands',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldives',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexico',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'New Caledonia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk Island',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Netherlands',
	'UserCountry_country_no' => 'Norway',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Neutral Zone',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'New Zealand',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'French Polynesia',
	'UserCountry_country_pg' => 'Papua New Guinea',
	'UserCountry_country_ph' => 'Philippines',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Poland',
	'UserCountry_country_pm' => 'Saint Pierre and Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestinian Territory',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunion Island',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_ru' => 'Russia',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi Arabia',
	'UserCountry_country_sb' => 'Solomon Islands',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Sweden',
	'UserCountry_country_sf' => 'Finland',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Saint Helena',
	'UserCountry_country_si' => 'Slovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Sao Tome and Principe',
	'UserCountry_country_su' => 'Old U.S.S.R',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syrian Arab Republic',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks and Caicos Islands',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'French Southern Territories',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tajikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'East Timor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'East Timor',
	'UserCountry_country_tr' => 'Turkey',
	'UserCountry_country_tt' => 'Trinidad and Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania, United Republic of',
	'UserCountry_country_ua' => 'Ukraine',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'United Kingdom',
	'UserCountry_country_um' => 'United States Minor Outlying Islands',
	'UserCountry_country_us' => 'United States',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatican City',
	'UserCountry_country_vc' => 'Saint Vincent and the Grenadines',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Virgin Islands, British',
	'UserCountry_country_vi' => 'Virgin Islands, U.S.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis and Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Yugoslavia',
	'UserCountry_country_za' => 'South Africa',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europe',
	'UserCountry_continent_afr' => 'Africa',
	'UserCountry_continent_asi' => 'Asia',
	'UserCountry_continent_amn' => 'North America',
	'UserCountry_continent_ams' => 'South and Central America',
	'UserCountry_continent_oce' => 'Oceania',
	'UserSettings_BrowserFamilies' => 'Tip browser',
	'UserSettings_Browsers' => 'Browsere',
	'UserSettings_Plugins' => 'Pluginuri',
	'UserSettings_Configurations' => 'Configurare',
	'UserSettings_OperatingSystems' => 'Sisteme operare',
	'UserSettings_Resolutions' => 'Rezolutii',
	'UserSettings_WideScreen' => 'Ecran extins',
	'UserSettings_WidgetResolutions' => 'Rezolutii ecran',
	'UserSettings_WidgetBrowsers' => 'Browsere vizitatori',
	'UserSettings_WidgetPlugins' => 'Lista pluginurilor',
	'UserSettings_WidgetWidescreen' => 'Normal / Ecran extins',
	'UserSettings_WidgetBrowserFamilies' => 'Browser dupa familie',
	'UserSettings_WidgetOperatingSystems' => 'Sisteme operare',
	'UserSettings_WidgetGlobalVisitors' => 'Configurare vizitatori globala',
	'UserSettings_SubmenuSettings' => 'Setari',
	'UsersManager_UsersManagement' => 'Management useri',
	'UsersManager_UsersManagementMainDescription' => 'Creaza user nou sau actualizeaza userul existent. Poti seta permisiunile lor.',
	'UsersManager_ManageAccess' => 'Manageriaza accesul',
	'UsersManager_MainDescription' => 'Decide userul ce are acces la propriul website . Poti de asemenea seta permisiunile la toate siteurile in acelasi timp.',
	'UsersManager_Sites' => 'Siteuri',
	'UsersManager_AllWebsites' => 'Toate siteurile',
	'UsersManager_ApplyToAllWebsites' => 'Aplica tuturor siteurilor',
	'UsersManager_User' => 'Utilizator',
	'UsersManager_PrivNone' => 'Fara acces',
	'UsersManager_PrivView' => 'Vezi',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_ChangeAllConfirm' => 'Esti sigur ca vrei sa scimbi \'%s\' permisiunile tuturor siteurilor?',
	'UsersManager_Password' => 'Parola',
	'UsersManager_Email' => 'Email',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Edit' => 'Editeaza',
	'UsersManager_AddUser' => 'Adauga user',
	'UsersManager_MenuUsers' => 'Useri',
	'UsersManager_DeleteConfirm_js' => 'Esti sigur ca vrei sa stergi userul %s?',
	'UsersManager_ExceptionLoginExists' => 'Login \'%s\' exista deja.',
	'UsersManager_ExceptionEmailExists' => 'Userul \'%s\' exista deja.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'The login must be between %1$s and %2$s characters long and contain only letters, numbers, or the characters \'_\' or \'-\' or \'.\'',
	'UsersManager_ExceptionInvalidEmail' => 'Emailul nu are un format valid.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Userul \'%s\' nu exista pentru ca a fost sters.',
	'UsersManager_ExceptionAdminAnonymous' => 'Nu poti autoriza \'admin\' accesul la \'anonymous\' user.',
	'UsersManager_ExceptionEditAnonymous' => 'Userul anonim nu poate fi editat sau sters.De exemplu poti face ca statisticile tale sa fie publice autorizand \'view\' accesul la \'anonymous\' user.',
	'UsersManager_ExceptionUserDoesNotExist' => 'User \'%s\' nu exista.',
	'UsersManager_ExceptionAccessValues' => 'The parameter access must have one of the following values : [ %s ]',
	'VisitFrequency_Evolution' => 'Evolutii peste perioada',
	'VisitFrequency_ReturnVisits' => '%s vizitatori intorsi',
	'VisitFrequency_ReturnActions' => '%s actiuni ale vizitatorilor intorsi',
	'VisitFrequency_WidgetOverview' => 'Rezumat periodic',
	'VisitFrequency_WidgetGraphReturning' => 'Graficul vizitelor intoarse',
	'VisitFrequency_SubmenuFrequency' => 'Frecventa',
	'VisitorInterest_VisitsPerDuration' => 'Vizite per durata',
	'VisitorInterest_VisitsPerNbOfPages' => 'Vizite per numar pagini',
	'VisitorInterest_WidgetLengths' => 'Durata vizitelor',
	'VisitorInterest_WidgetPages' => 'Pagini per vizita',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_OnePage' => '1 pagina',
	'VisitorInterest_NPages' => '%s pagini',
	'VisitsSummary_NbVisits' => '%s vizitari',
	'VisitsSummary_NbUniqueVisitors' => '%s vizitatori unici',
	'VisitsSummary_MaxNbActions' => '%s actiuni maxime pe vizita',
	'VisitsSummary_GenerateTime' => '%s secunde pentru generarea pagini',
	'VisitsSummary_GenerateQueries' => '%s interogari executate',
	'VisitsSummary_WidgetLastVisits' => 'Grafic ultima vizita',
	'VisitsSummary_WidgetVisits' => 'Rezumatul vizitelor',
	'VisitsSummary_WidgetLastVisitors' => 'Grafic ultimi vizitatori unici',
	'VisitsSummary_WidgetOverviewGraph' => 'Rezumatul grafic',
	'VisitsSummary_SubmenuOverview' => 'Rezumat',
	'VisitTime_PluginDescription' => 'Afişează ora locală şi cea a serverului. Timpul serverului poate fi folositor pentru a programa mentenanţa Websiteului.',
	'VisitTime_LocalTime' => 'Vizite pe timpul local',
	'VisitTime_ServerTime' => 'Vizite pe timpul serverului',
	'VisitTime_ColumnServerTime' => 'Ora serverului',
	'VisitTime_ColumnLocalTime' => 'Ora locală',
	'VisitTime_WidgetLocalTime' => 'Vizite dupa timpul local',
	'VisitTime_WidgetServerTime' => 'Vizite dupa timpul serverului',
	'VisitTime_SubmenuTimes' => 'Timp',
	'VisitTime_NHour' => '%sh',
	'Annotations_Annotations' => 'Note',
	'Annotations_EnterAnnotationText' => 'Introdu nota...',
	'Annotations_IconDesc_js' => 'Vezi notele pentru aceasta data de interval.',
	'Annotations_ViewAndAddAnnotations_js' => 'Vezi si adauga nota pentru %s...',
	'Annotations_ClickToDelete' => 'Click pentru a sterge acesta nota',
	'Annotations_ClickToStarOrUnstar' => 'Click pentru a marca sau demarca aceasta nota.',
	'Annotations_LoginToAnnotate' => 'Conecteaza-te pentru a crea o nota.',
	'Annotations_AnnotationOnDate' => 'Comentariu in %1$s: %2$s',
	'UserLanguage_Language_ab' => 'abhază',
	'UserLanguage_Language_af' => 'afrikaans',
	'UserLanguage_Language_am' => 'amharică',
	'UserLanguage_Language_an' => 'aragoneză',
	'UserLanguage_Language_ar' => 'arabă',
	'UserLanguage_Language_as' => 'asameză',
	'UserLanguage_Language_av' => 'avară',
	'UserLanguage_Language_ay' => 'aymara',
	'UserLanguage_Language_az' => 'azeră',
	'UserLanguage_Language_ba' => 'bașkiră',
	'UserLanguage_Language_be' => 'bielorusă',
	'UserLanguage_Language_bg' => 'bulgară',
	'UserLanguage_Language_bh' => 'bihari',
	'UserLanguage_Language_bn' => 'bengaleză',
	'UserLanguage_Language_bo' => 'tibetană',
	'UserLanguage_Language_br' => 'bretonă',
	'UserLanguage_Language_bs' => 'bosniacă',
	'UserLanguage_Language_ca' => 'catalană',
	'UserLanguage_Language_ce' => 'cecenă',
	'UserLanguage_Language_co' => 'corsicană',
	'UserLanguage_Language_cs' => 'cehă',
	'UserLanguage_Language_cu' => 'slavonă',
	'UserLanguage_Language_cv' => 'ciuvașă',
	'UserLanguage_Language_cy' => 'velșă',
	'UserLanguage_Language_da' => 'daneză',
	'UserLanguage_Language_de' => 'germană',
	'UserLanguage_Language_el' => 'greacă',
	'UserLanguage_Language_en' => 'engleză',
	'UserLanguage_Language_eo' => 'esperanto',
	'UserLanguage_Language_es' => 'spaniolă',
	'UserLanguage_Language_et' => 'estoniană',
	'UserLanguage_Language_eu' => 'bască',
	'UserLanguage_Language_fa' => 'persană',
	'UserLanguage_Language_fi' => 'finlandeză',
	'UserLanguage_Language_fj' => 'fijiană',
	'UserLanguage_Language_fo' => 'faroeză',
	'UserLanguage_Language_fr' => 'franceză',
	'UserLanguage_Language_fy' => 'frizonă occidentală',
	'UserLanguage_Language_ga' => 'irlandeză',
	'UserLanguage_Language_gd' => 'gaelică scoțiană',
	'UserLanguage_Language_gl' => 'galiciană',
	'UserLanguage_Language_gn' => 'guarani',
	'UserLanguage_Language_gu' => 'gujarati',
	'UserLanguage_Language_he' => 'ebraică',
	'UserLanguage_Language_hi' => 'hindi',
	'UserLanguage_Language_hr' => 'croată',
	'UserLanguage_Language_ht' => 'haitiană',
	'UserLanguage_Language_hu' => 'maghiară',
	'UserLanguage_Language_hy' => 'armeană',
	'UserLanguage_Language_ia' => 'interlingua',
	'UserLanguage_Language_id' => 'indoneziană',
	'UserLanguage_Language_ie' => 'interlingue',
	'UserLanguage_Language_ik' => 'inupiak',
	'UserLanguage_Language_is' => 'islandeză',
	'UserLanguage_Language_it' => 'italiană',
	'UserLanguage_Language_ja' => 'japoneză',
	'UserLanguage_Language_jv' => 'javaneză',
	'UserLanguage_Language_ka' => 'georgiană',
	'UserLanguage_Language_kg' => 'congoleză',
	'UserLanguage_Language_kk' => 'kazahă',
	'UserLanguage_Language_kl' => 'kalaallisut',
	'UserLanguage_Language_km' => 'khmeră',
	'UserLanguage_Language_kn' => 'kannada',
	'UserLanguage_Language_ko' => 'coreeană',
	'UserLanguage_Language_ks' => 'cașmireză',
	'UserLanguage_Language_ku' => 'kurdă',
	'UserLanguage_Language_ky' => 'kîrgîză',
	'UserLanguage_Language_la' => 'latină',
	'UserLanguage_Language_lb' => 'luxemburgheză',
	'UserLanguage_Language_ln' => 'lingala',
	'UserLanguage_Language_lo' => 'laoțiană',
	'UserLanguage_Language_lt' => 'lituaniană',
	'UserLanguage_Language_lv' => 'letonă',
	'UserLanguage_Language_mg' => 'malgașă',
	'UserLanguage_Language_mi' => 'maori',
	'UserLanguage_Language_mk' => 'macedoneană',
	'UserLanguage_Language_ml' => 'malayalam',
	'UserLanguage_Language_mn' => 'mongolă',
	'UserLanguage_Language_mr' => 'marathi',
	'UserLanguage_Language_ms' => 'malay',
	'UserLanguage_Language_mt' => 'malteză',
	'UserLanguage_Language_my' => 'birmaneză',
	'UserLanguage_Language_ne' => 'nepaleză',
	'UserLanguage_Language_nl' => 'olandeză',
	'UserLanguage_Language_nn' => 'norvegiană nynorsk',
	'UserLanguage_Language_no' => 'norvegiană',
	'UserLanguage_Language_nv' => 'navajo',
	'UserLanguage_Language_oc' => 'occitană',
	'UserLanguage_Language_om' => 'oromo',
	'UserLanguage_Language_or' => 'oriya',
	'UserLanguage_Language_pa' => 'punjabi',
	'UserLanguage_Language_pi' => 'pali',
	'UserLanguage_Language_pl' => 'poloneză',
	'UserLanguage_Language_ps' => 'pașto',
	'UserLanguage_Language_pt' => 'portugheză',
	'UserLanguage_Language_qu' => 'quechua',
	'UserLanguage_Language_rm' => 'retoromană',
	'UserLanguage_Language_ro' => 'română',
	'UserLanguage_Language_ru' => 'rusă',
	'UserLanguage_Language_sa' => 'sanscrită',
	'UserLanguage_Language_sc' => 'sardiniană',
	'UserLanguage_Language_sd' => 'sindhi',
	'UserLanguage_Language_si' => 'singaleză',
	'UserLanguage_Language_sk' => 'slovacă',
	'UserLanguage_Language_sl' => 'slovenă',
	'UserLanguage_Language_sm' => 'samoană',
	'UserLanguage_Language_so' => 'somaleză',
	'UserLanguage_Language_sq' => 'albaneză',
	'UserLanguage_Language_sr' => 'sârbă',
	'UserLanguage_Language_st' => 'sesotho',
	'UserLanguage_Language_su' => 'sundaneză',
	'UserLanguage_Language_sv' => 'suedeză',
	'UserLanguage_Language_sw' => 'swahili',
	'UserLanguage_Language_ta' => 'tamilă',
	'UserLanguage_Language_te' => 'telugu',
	'UserLanguage_Language_tg' => 'tadjică',
	'UserLanguage_Language_th' => 'thailandeză',
	'UserLanguage_Language_ti' => 'tigrinya',
	'UserLanguage_Language_tk' => 'turkmenă',
	'UserLanguage_Language_tl' => 'tagalog',
	'UserLanguage_Language_tn' => 'setswana',
	'UserLanguage_Language_tr' => 'turcă',
	'UserLanguage_Language_tt' => 'tătară',
	'UserLanguage_Language_tw' => 'twi',
	'UserLanguage_Language_ty' => 'tahitiană',
	'UserLanguage_Language_ug' => 'uigură',
	'UserLanguage_Language_uk' => 'ucraineană',
	'UserLanguage_Language_ur' => 'urdu',
	'UserLanguage_Language_uz' => 'uzbecă',
	'UserLanguage_Language_vi' => 'vietnameză',
	'UserLanguage_Language_vo' => 'volapuk',
	'UserLanguage_Language_wa' => 'valonă',
	'UserLanguage_Language_wo' => 'wolof',
	'UserLanguage_Language_xh' => 'xhosa',
	'UserLanguage_Language_yi' => 'idiș',
	'UserLanguage_Language_yo' => 'yoruba',
	'UserLanguage_Language_zh' => 'chineză',
	'UserLanguage_Language_zu' => 'zulu',
);
